@@ -27,7 +27,7 @@
 #include <string.h>
 
 #include <gtk/gtk.h>
-#include <libgnomevfs/gnome-vfs.h>
+#include <libgnomeui/gnome-help.h>
 #include <panel-applet.h>
 
 #include "drive-list.h"
@@ -79,30 +79,17 @@ static void
 change_background (PanelApplet               *applet,
 		   PanelAppletBackgroundType  type,
 		   GdkColor                  *colour,
-		   GdkPixmap                 *pixmap)
+		   GdkPixmap                 *pixmap,
+		   DriveList                 *drivelist)
 {
-    GtkRcStyle *rc_style;
-    GtkStyle *style;
-
-    /* reset style */
-    gtk_widget_set_style (GTK_WIDGET (applet), NULL);
-    rc_style = gtk_rc_style_new ();
-    gtk_widget_modify_style (GTK_WIDGET (applet), rc_style);
-    g_object_unref (rc_style);
-
     switch (type) {
     case PANEL_NO_BACKGROUND:
+	drive_list_set_transparent (drivelist, FALSE);
 	break;
+
     case PANEL_COLOR_BACKGROUND:
-	gtk_widget_modify_bg (GTK_WIDGET (applet),
-			      GTK_STATE_NORMAL, colour);
-	break;
     case PANEL_PIXMAP_BACKGROUND:
-	style = gtk_style_copy (GTK_WIDGET (applet)->style);
-	if (style->bg_pixmap[GTK_STATE_NORMAL])
-	    g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
-	style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
-	gtk_widget_set_style (GTK_WIDGET (applet), style);
+	drive_list_set_transparent (drivelist, TRUE);
 	break;
     }
 }
@@ -123,14 +110,13 @@ display_about_dialog (BonoboUIComponent *uic,
     };
 
     gtk_show_about_dialog (NULL,
-	"name",        _("Disk Mounter"),
 	"version",     VERSION,
 	"copyright",   "Copyright \xC2\xA9 2004 Canonical Ltd",
 	"comments",    _("Applet for mounting and unmounting block volumes."),
 	"authors",     authors,
 	"documenters", documenters,
-	"translator-credits", _("translator_credits"),
-	"logo_icon_name",     "gnome-dev-jazdisk",
+	"translator-credits", _("translator-credits"),
+	"logo_icon_name",     "media-floppy",
 	NULL);
 }
 
@@ -177,14 +163,18 @@ applet_factory (PanelApplet *applet,
 {
     gboolean ret = FALSE;
     GtkWidget *drive_list;
+    AtkObject *ao;
 
     if (!strcmp (iid, drivemount_iid)) {
-	gtk_window_set_default_icon_name ("gnome-dev-jazdisk");
+	g_set_application_name (_("Disk Mounter"));
+
+	gtk_window_set_default_icon_name ("media-floppy");
 
 	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
 	panel_applet_add_preferences (applet,
 				      "/schemas/apps/drivemount-applet/prefs",
 				      NULL);
+	panel_applet_set_background_widget (applet, GTK_WIDGET (applet));
 
 	drive_list = drive_list_new ();
 	gtk_container_add (GTK_CONTAINER (applet), drive_list);
@@ -194,7 +184,7 @@ applet_factory (PanelApplet *applet,
 	g_signal_connect_object (applet, "size_allocate",
 				 G_CALLBACK (size_allocate), drive_list, 0);
 	g_signal_connect (applet, "change_background",
-			  G_CALLBACK (change_background), NULL);
+			  G_CALLBACK (change_background), drive_list);
 
 	/* set initial state */
 	change_orient (applet,
@@ -207,6 +197,9 @@ applet_factory (PanelApplet *applet,
 					   NULL, applet_menu_verbs,
 					   drive_list);
 
+	ao = gtk_widget_get_accessible (GTK_WIDGET (applet));
+	atk_object_set_name (ao, _("Disk Mounter"));
+
 	gtk_widget_show_all (GTK_WIDGET (applet));
 
 	ret = TRUE;
