@@ -27,7 +27,6 @@
 
 #include <gtk/gtkicontheme.h>
 #include <gtk/gtkimage.h>
-#include <gtk/gtktooltips.h>
 #include <gconf/gconf-client.h>
 #include <panel-applet-gconf.h>
 #include <gst/gst.h>
@@ -63,6 +62,8 @@ typedef struct _GnomeVolumeApplet {
   /* the docked window containing the volume widget */
   GnomeVolumeAppletDock *dock;
   gboolean pop;
+  /* the adjustment connected to the dock slider */
+  GtkAdjustment *adjustment;
 
   /* list of volume control elements */
   GList *elements;
@@ -72,6 +73,7 @@ typedef struct _GnomeVolumeApplet {
 
   /* element */
   GstMixer *mixer;
+  GstBus *bus;
   gboolean lock;
   gint state;
   GList *tracks;
@@ -87,7 +89,6 @@ typedef struct _GnomeVolumeApplet {
   gint panel_size;
 
   /* use same object for setting tooltop */
-  GtkTooltips *tooltips;
   gboolean force_next_update;
 } GnomeVolumeApplet;
 
